@@ -3,11 +3,12 @@ package Coro::PatchSet;
 use strict;
 use Carp;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 my %known_classes = (
 	socket => 'Coro/PatchSet/Socket.pm',
-	handle => 'Coro/PatchSet/Handle.pm'
+	handle => 'Coro/PatchSet/Handle.pm',
+	lwp    => 'Coro/PatchSet/LWP.pm',
 );
 
 sub import {
@@ -70,7 +71,7 @@ works for you. So, try to install it and if this will ok, then it is probably co
 
 =head1 SEE ALSO
 
-L<Coro::PatchSet::Socket>, L<Coro::PatchSet::Handle>
+L<Coro::PatchSet::Socket>, L<Coro::PatchSet::Handle>, L<Coro::PatchSet::LWP>
 
 =head1 COPYRIGHT
 
